@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Result;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains the result of a JSON Schema evaluation
 
-our $VERSION = '0.549';
+our $VERSION = '0.550';
 
 use 5.020;
 use Moo;
@@ -162,6 +162,12 @@ sub TO_JSON ($self) {
   $self->format($self->output_format);
 }
 
+sub dump ($self) {
+  my $encoder = JSON::MaybeXS->new(utf8 => 0, convert_blessed => 1, canonical => 1, pretty => 1);
+  $encoder->indent_length(2) if $encoder->can('indent_length');
+  $encoder->encode($self);
+}
+
 # turns the JSON pointers in instance_location, keyword_location  into a URI fragments,
 # for strict draft-201909 adherence
 sub _map_uris ($data) {
@@ -186,7 +192,7 @@ JSON::Schema::Modern::Result - Contains the result of a JSON Schema evaluation
 
 =head1 VERSION
 
-version 0.549
+version 0.550
 
 =head1 SYNOPSIS
 
@@ -297,6 +303,11 @@ is false.
 When provided with another result object, returns a new object with the combination of all results.
 See C<&> at L</OVERLOADS>.
 
+=head2 dump
+
+Returns a JSON string representing the result object, using the requested L</format>, according to
+the L<specification|https://json-schema.org/draft/2019-09/json-schema-core.html#rfc.section.10>.
+
 =for stopwords OpenAPI
 
 =head1 SUPPORT
